==> xmgfv1.9.1.tar.gz: xmgf/inc/InitX.h <==
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

/********************************************************
*  Routine Name: InitColors()
*  Derived From: Anthony Tai - Xgf - 1991
*  Colour Selection Stages
********************************************************/
#include <X11/Xlib.h>

#define maxPixels 85
extern Colormap        theCMap;
extern Display        *theDisplay;
extern GC              theGC;
extern int             theScreen;
extern Pixmap   bbuf;
extern Drawable theDrawable;
extern unsigned int  theDepth;
extern int      theRootWindow;
extern int      maxcolorpixels;
extern unsigned long colorpixels[151];
extern char    *theColorNames[maxPixels + 1];
extern int 	NumColors;

#ifndef _NO_PROTO
void            InitColors (void);
void            SetColor (int i);
void            CreateBuff (Window win, int x, int y);
void            SwapBuff (Window win, int x, int y);
void            ClearBuff (Window win, int x, int y);
XColor          GetRGB (int index);
void		 LoadColourMap(char *filename,int MAPType);
void		ChangeTile(int Tile);
void		InitTiles(void);
void		CheckDither(void);
void		ReturnDither(void);
#else
void            InitColors ();
void            SetColor ();
void            CreateBuff ();
void            SwapBuff ();
void            ClearBuff ();
XColor          GetRGB ();
void		LoadColourMap();
void		ChangeTile();
void		InitTiles();
void		CheckDither();
void		ReturnDither();
#endif

==> xmgfv2.4.tar.gz: xmgf/inc/InitX.h <==
/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

/********************************************************
*  Routine Name: InitColors()
*  Derived From: Anthony Tai - Xgf - 1991
*  Colour Selection Stages
********************************************************/
#include <X11/Xlib.h>

#define maxPixels 85
extern Colormap        theCMap;
extern Display        *theDisplay;
extern GC              theGC;
extern int             theScreen;
extern Pixmap   bbuf;
extern Drawable theDrawable;
extern unsigned int  theDepth;
extern int      theRootWindow;
extern int      maxcolorpixels;
extern unsigned long colorpixels[151];
extern char    *theColorNames[maxPixels + 1];
extern int 	NumColors;

#ifndef _NO_PROTO
void            InitColors (void);
void            SetColor (int i);
void            CreateBuff (Window win, int x, int y);
void            SwapBuff (Window win, int x, int y);
void		DestroyBuff(void);
void            ClearBuff (Window win, int x, int y);
XColor          GetRGB (int index);
void		 LoadColourMap(char *filename,int MAPType);
void		ChangeTile(int Tile);
void		InitTiles(void);
void		CheckDither(void);
void		ReturnDither(void);
void		ChangeSphere(int Size);
void		CheckSphere(void);
void		ReturnSphere(void);
#else
void            InitColors ();
void            SetColor ();
void            CreateBuff ();
void            SwapBuff ();
void		DestroyBuff();
void            ClearBuff ();
XColor          GetRGB ();
void		LoadColourMap();
void		ChangeTile();
void		InitTiles();
void		CheckDither();
void		ReturnDither();
void		ChangeSphere();
void		CheckSphere();
void		ReturnSphere();
#endif
